@@ -224,10 +224,12 @@ def fprint(*s):
 if __name__ == "__main__":
     while True:
         try:
-            main()
-        except (KeyboardInterrupt, SystemExit):
+            main(prog_name="python -m telegram_updates_tweets")
+        except KeyboardInterrupt:
             print("bye")
             break
+        except SystemExit:
+            break
         except Exception as e:
             fprint("Error:", str(e))
             fprint("Sleeping 60s")
